@@ -1,9 +1,11 @@
 from .actor import Actor
 from .automator import Automator
-from .usb_camera_capture import UsbCameraCapture
-from .usb_camera_simulator import UsbCameraSimulator
+from .camera_projector import CameraProjector
 from .detector import Detector
 from .lizard import Lizard
+from .network_monitor import NetworkMonitor, NetworkStats
 from .odometer import Odometer
 from .steerer import Steerer
-from .camera_projector import CameraProjector
+from .usb_camera_capture import UsbCameraCapture
+from .usb_camera_simulator import UsbCameraSimulator
+from .backup import Backup
