@@ -3,12 +3,11 @@ from nicegui import ui
 import pylab as pl
 import numpy as np
 import time
-from rosys.world.pose import Pose
-from rosys.world.spline import Spline
-from grid import Grid
-from robot_renderer import RobotRenderer
-from obstacle_map import ObstacleMap
-import plot_tools as pt
+from rosys.world import Pose, Spline
+from rosys.pathplanning.grid import Grid
+from rosys.pathplanning.robot_renderer import RobotRenderer
+from rosys.pathplanning.obstacle_map import ObstacleMap
+import rosys.pathplanning.plot_tools as pt
 
 grid = Grid((30, 40, 36), (0.45, -0.05, 4.0, 3.0))
 obstacles = [
