@@ -3,11 +3,12 @@ from asyncio.exceptions import CancelledError
 import asyncio
 import logging
 from typing import Optional, Type
-from . import event, task_logger
-from .actors import Actor, Automator, Lizard, Odometer, Steerer, UsbCameraCapture, UsbCameraSimulator
+
+from . import event, task_logger, run
+from .actors import Actor, Automator, Lizard, Odometer, Steerer, UsbCameraCapture, UsbCameraSimulator, NetworkMonitor, Backup
 from .hardware import Hardware, SimulatedHardware
 from .persistence import Persistence
-from .world import AutomationState, Mode, World
+from .world import Mode, World
 
 
 class Runtime:
@@ -20,23 +21,24 @@ class Runtime:
         self.world = world or World()
         Actor.world = self.world
         self.tasks = []
-
         if self.world.mode != Mode.TEST:
             self.persistence = persistence or Persistence(self.world)
             self.persistence.restore()
-
         self.hardware = hardware or SimulatedHardware(self.world)
         self.lizard = Lizard(self.hardware)
         self.odometer = Odometer()
         self.steerer = Steerer(self.hardware)
         self.automator = Automator()
-
         self.actors = [
             self.lizard,
             self.odometer,
             self.steerer,
             self.automator,
         ]
+        if NetworkMonitor.is_operable():
+            self.with_actors(NetworkMonitor())
+        if self.world.mode != Mode.TEST:
+            self.with_actors(Backup(self.persistence))
 
     def with_actors(self, *actors: list[Actor]):
         '''Adds list of additional actors to runtime.'''
@@ -50,21 +52,6 @@ class Runtime:
         else:
             self.with_actors(UsbCameraSimulator())
 
-    async def pause(self, because: Optional[str] = None):
-        await event.call(event.Id.PAUSE_AUTOMATIONS, because)
-
-    async def stop(self, because: Optional[str] = None):
-        await event.call(event.Id.PAUSE_AUTOMATIONS, because)
-        self.automator.routines.clear()
-        self.world.automation_state = AutomationState.STOPPED
-
-    async def resume(self):
-        previous = self.world.automation_state
-        if previous != AutomationState.DISABLED:
-            self.world.automation_state = AutomationState.RUNNING
-            if previous == AutomationState.STOPPED:
-                event.emit(event.Id.AUTOMATIONS_STARTED)
-
     async def startup(self):
         if self.tasks:
             raise Exception('should be only executed once')
@@ -85,7 +72,8 @@ class Runtime:
         if self.world.mode != Mode.TEST:
             self.persistence.backup()
         [t.cancel() for t in self.tasks]
-        Actor.process_pool.shutdown()
+        if self.world.mode != Mode.TEST:
+            run.process_pool.shutdown()
         await asyncio.gather(*[task_logger.create_task(a.tear_down(), name=f'{a.name}.tear_down()') for a in self.actors])
 
     async def repeat(self, actor: Actor):
