@@ -1,7 +1,10 @@
+from .area import Area
 from .calibration import Calibration, Intrinsics, Extrinsics
 from .camera import Camera
 from .detection import Detection, BoxDetection, PointDetection
 from .image import Image, ImageSize
+from .line import Line
+from .line_segment import LineSegment
 from .mode import Mode
 from .obstacle import Obstacle
 from .path_segment import PathSegment
@@ -14,4 +17,4 @@ from .spline import Spline
 from .upload import Upload
 from .usb_camera import UsbCamera
 from .velocity import Velocity
-from .world import World, AutomationState
+from .world import World
